# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {}

modules = []

doc_url = "https://nlpbook.github.io/nlpbook/"

git_url = "https://github.com/nlpbook/nlpbook/tree/master/"

def custom_doc_links(name): return None
